summaryrefslogtreecommitdiff
path: root/sd/inc/Outliner.hxx
diff options
context:
space:
mode:
authorOliver Bolte <obo@openoffice.org>2004-04-27 15:00:53 +0000
committerOliver Bolte <obo@openoffice.org>2004-04-27 15:00:53 +0000
commite14f4522a3f46863e7a183988fa7283a1eadd52f (patch)
tree4370e56c4e8ad0f2742f0c0740aa7b2d58e13002 /sd/inc/Outliner.hxx
parent9fd5758ef1549366c87372d629b57eb52ce38deb (diff)
INTEGRATION: CWS tl01 (1.2.12); FILE MERGED
2004/02/19 13:34:54 af 1.2.12.1: #112058# Incorporated changes made in sdoutl.cxx for Hangul/Hanja conversion.
Diffstat (limited to 'sd/inc/Outliner.hxx')
-rw-r--r--sd/inc/Outliner.hxx41
1 files changed, 37 insertions, 4 deletions
diff --git a/sd/inc/Outliner.hxx b/sd/inc/Outliner.hxx
index bbc638a4ca93..fce9243d9529 100644
--- a/sd/inc/Outliner.hxx
+++ b/sd/inc/Outliner.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: Outliner.hxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: obo $ $Date: 2004-01-20 10:13:55 $
+ * last change: $Author: obo $ $Date: 2004-04-27 16:00:53 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -190,11 +190,28 @@ public:
or spell check.
*/
void EndSpelling (void);
+
+ /** callback for hangul hanja textconversion */
+ sal_Bool ConvertNextDocument (void);
+
+ /** Starts the hangul hanja text conversion for the current viewshell */
+ void StartTextConversion ( INT16 nLanguage );
+
+ /** This is called internaly when text conversion is started.
+ The position of current view mode/page/object/caret position
+ is remembered and will be restored after conversion.
+ */
+ void BeginConversion (void);
+
+ /** Release all resources that have been created during the conversion */
+ void EndConversion (void);
+
DECL_LINK( SpellError, void * );
private:
- /// Specifies whether to search and replace or to spell check.
- enum {SEARCH, SPELL} meMode;
+ /// Specifies whether to search and replace, to spell check or to do a
+ /// hangul hanja conversion.
+ enum {SEARCH, SPELL, HANGUL_HANJA_CONVERSION} meMode;
/// The view which displays the searched objects.
::sd::View* mpView;
@@ -205,6 +222,11 @@ private:
/// The document on whose objects and pages this class operates.
SdDrawDocument* mpDrawDocument;
+ /** this is the language that is used for current text conversion.
+ Only valid if meMode is HANGUL_HANJA_CONVERSION.
+ */
+ INT16 mnConversionLanguage;
+
/** Flag that specifies whether we own the outline view pointed to by
<member>mpOutlineView</member> and thus have to
delete it in <member>EndSpelling()</member>.
@@ -283,6 +305,12 @@ private:
*/
SdrObject* mpObj;
+ /** this stores the first object that is used for hangul/hanja conversion.
+ Conversion automaticly wraps around the document and stops when it
+ finds this object again.
+ */
+ SdrObject* mpFirstObj;
+
/// Candidate for being searched/spell checked.
SdrTextObj* mpTextObj;
@@ -443,6 +471,11 @@ private:
*/
void PrepareSearchAndReplace (void);
+ /** Prepare to do a hangul hanja conversion on the current text
+ object. This includes putting it into edit mode.
+ */
+ void PrepareHangulHanjaConversion (void);
+
/** Switch to a new view mode. Try to restore the original edit mode
before doing so.
@param ePageKind